@@ -60,10 +60,10 @@ update_pass_cb (PgmViewport *viewport,
   return TRUE;
 }
 
-/* Start rotating the image when the pixbuf is loaded */
+/* Start rotating the image when the file is loaded */
 static void
-pixbuf_loaded_cb (PgmImage *image,
-                  gpointer data)
+file_loaded_cb (PgmImage *image,
+                gpointer data)
 {
   PgmViewport *viewport = PGM_VIEWPORT (data);
 
@@ -97,8 +97,8 @@ main (int argc,
 
   /* Scene setup */
   img = pgm_image_new_from_file ("examples/pictures/star.png", 0);
-  g_signal_connect (G_OBJECT (img), "pixbuf-loaded",
-                    G_CALLBACK (pixbuf_loaded_cb), viewport);
+  g_signal_connect (G_OBJECT (img), "file-loaded",
+                    G_CALLBACK (file_loaded_cb), viewport);
   pgm_drawable_set_size (img, 3.0f, 3.0f);
   pgm_drawable_set_position (img, 0.5f, 0.0f, 0.0f);
   pgm_drawable_set_bg_color (img, 1.0f, 1.0f, 1.0f, 0.0f);
