@@ -125,6 +125,8 @@ main (int argc,
   pgm_drawable_set_size (img, 400, 400);
   pgm_drawable_set_position (img, 100, 100, 0);
   pgm_drawable_set_bg_color (img, 0, 0, 255, 0);
+  pgm_image_set_wrapping (PGM_IMAGE (img), PGM_IMAGE_TRANSPARENT,
+                          PGM_IMAGE_TRANSPARENT);
   pgm_drawable_show (img);
 
   /* Text definition */
