@@ -352,8 +352,8 @@ pgm_canvas_set_size (PgmCanvas *canvas,
 
   GST_OBJECT_LOCK (canvas);
 
-  canvas->width = width;
-  canvas->height = height;
+  canvas->width = MAX (1.0f, width);
+  canvas->height = MAX (1.0f, height);
 
   GST_OBJECT_UNLOCK (canvas);
 
@@ -779,11 +779,21 @@ pgm_canvas_get_order (PgmCanvas *canvas,
   g_return_val_if_fail (order != NULL, PGM_ERROR_X);
 
   GST_OBJECT_LOCK (drawable);
-  *layer = drawable->layer;
-  GST_OBJECT_UNLOCK (drawable);
-
   GST_OBJECT_LOCK (canvas);
 
+  if (G_UNLIKELY ((gpointer) GST_OBJECT_PARENT (drawable) != (gpointer) canvas))
+    {
+      GST_WARNING_OBJECT (canvas, "not the parent of %s",
+                          GST_STR_NULL (GST_OBJECT_NAME (drawable)));
+      GST_OBJECT_UNLOCK (drawable);
+      GST_OBJECT_UNLOCK (canvas);
+      return PGM_ERROR_X;
+    }
+
+  *layer = drawable->layer;
+
+  GST_OBJECT_UNLOCK (drawable);
+
   switch (*layer)
     {
     case PGM_DRAWABLE_NEAR:
