@@ -104,8 +104,9 @@ enum {
 /* Drawable internal flags */
 enum {
   PGM_DRAWABLE_ROTATED       = (1 << 0),
-  PGM_DRAWABLE_PLANE_VECTORS = (1 << 1),
-  PGM_DRAWABLE_ORIGIN        = (1 << 2)
+  PGM_DRAWABLE_SCALED        = (1 << 1),
+  PGM_DRAWABLE_PLANE_VECTORS = (1 << 2),
+  PGM_DRAWABLE_ORIGIN        = (1 << 3)
 };
 
 static GstObjectClass *parent_class = NULL;
@@ -126,9 +127,9 @@ update_transformation_matrix (PgmDrawable *drawable)
 
   /* Update the matrix with a translation to the center of the drawable */
   pgm_mat4x4_set_from_scalars (drawable->transformation_matrix,
-                               1.0f, 0.0f, 0.0f, x_offset,
-                               0.0f, 1.0f, 0.0f, y_offset,
-                               0.0f, 0.0f, 1.0f, drawable->z,
+                               drawable->scale, 0.0f, 0.0f, x_offset,
+                               0.0f, drawable->scale, 0.0f, y_offset,
+                               0.0f, 0.0f, drawable->scale, drawable->z,
                                0.0f, 0.0f, 0.0f, 1.0f);
 
   /* Update the rotation from the center */
@@ -651,6 +652,7 @@ pgm_drawable_init (PgmDrawable *drawable)
   drawable->angle_x = 0.0f;
   drawable->angle_y = 0.0f;
   drawable->angle_z = 0.0f;
+  drawable->scale = 1.0f;
   /* Colors */
   drawable->fg_r = 255;
   drawable->fg_g = 255;
@@ -798,7 +800,7 @@ pgm_drawable_set_size (PgmDrawable *drawable,
   drawable->height = MAX (0.0f, height);
 
   /* Update the transformation matrix if the user added rotations */
-  if (drawable->flags & PGM_DRAWABLE_ROTATED)
+  if (drawable->flags & (PGM_DRAWABLE_ROTATED | PGM_DRAWABLE_SCALED))
     update_transformation_matrix (drawable);
 
   GST_OBJECT_UNLOCK (drawable);
@@ -808,7 +810,7 @@ pgm_drawable_set_size (PgmDrawable *drawable,
   if (klass->set_size)
     ret = klass->set_size (drawable, width, height);
 
-  if (drawable->flags & PGM_DRAWABLE_ROTATED)
+  if (drawable->flags & (PGM_DRAWABLE_ROTATED | PGM_DRAWABLE_SCALED))
     _pgm_drawable_emit_changed (drawable, PGM_DRAWABLE_TRANSFORMATION_MATRIX);
 
   _pgm_drawable_emit_changed (drawable, PGM_DRAWABLE_SIZE);
@@ -888,7 +890,7 @@ pgm_drawable_set_position (PgmDrawable *drawable,
   drawable->flags &= ~PGM_DRAWABLE_ORIGIN;
 
   /* Update the transformation matrix if the user added rotations */
-  if (drawable->flags & PGM_DRAWABLE_ROTATED)
+  if (drawable->flags & (PGM_DRAWABLE_ROTATED | PGM_DRAWABLE_SCALED))
     update_transformation_matrix (drawable);
 
   GST_OBJECT_UNLOCK (drawable);
@@ -908,7 +910,7 @@ pgm_drawable_set_position (PgmDrawable *drawable,
         _pgm_canvas_update_order (PGM_CANVAS (canvas), drawable);
     }
 
-  if (drawable->flags & PGM_DRAWABLE_ROTATED)
+  if (drawable->flags & (PGM_DRAWABLE_ROTATED | PGM_DRAWABLE_SCALED))
     _pgm_drawable_emit_changed (drawable, PGM_DRAWABLE_TRANSFORMATION_MATRIX);
 
   _pgm_drawable_emit_changed (drawable, PGM_DRAWABLE_POSITION);
@@ -1155,6 +1157,73 @@ pgm_drawable_get_rotation_z (PgmDrawable *drawable,
   return PGM_ERROR_OK;
 }
 
+/**
+ * pgm_drawable_set_scale:
+ * @drawable: a #PgmDrawable object.
+ * @scale: a scale factor.
+ *
+ * Defines the scale to apply to @drawable. The scaling point is the center of
+ * @drawable.
+ *
+ * MT safe.
+ *
+ * Returns: a #PgmError indicating success/failure.
+ */
+PgmError
+pgm_drawable_set_scale (PgmDrawable *drawable,
+                        gfloat scale)
+{
+  g_return_val_if_fail (PGM_IS_DRAWABLE (drawable), PGM_ERROR_X);
+
+  GST_OBJECT_LOCK (drawable);
+
+  if (scale == drawable->scale)
+    {
+      GST_OBJECT_UNLOCK (drawable);
+      return PGM_ERROR_OK;
+    }
+
+  drawable->scale = scale;
+  update_transformation_matrix (drawable);
+
+  /* Update flags to avoid further unneeded computations */
+  if (scale != 1.0f)
+    drawable->flags |= PGM_DRAWABLE_SCALED;
+  else
+    drawable->flags &= ~PGM_DRAWABLE_SCALED;
+
+  GST_OBJECT_UNLOCK (drawable);
+
+  _pgm_drawable_emit_changed (drawable, PGM_DRAWABLE_TRANSFORMATION_MATRIX);
+
+  return PGM_ERROR_OK;
+}
+
+/**
+ * pgm_drawable_get_scale:
+ * @drawable: a #PgmDrawable object.
+ * @scale: a #gfloat pointer where the scale factor is going to be stored.
+ *
+ * Retrieves in @scale the current scale factor applied to @drawable.
+ *
+ * MT safe.
+ *
+ * Returns: a #PgmError indicating success/failure.
+ */
+PgmError
+pgm_drawable_get_scale (PgmDrawable *drawable,
+                        gfloat *scale)
+{
+  g_return_val_if_fail (PGM_IS_DRAWABLE (drawable), PGM_ERROR_X);
+  g_return_val_if_fail (scale != NULL, PGM_ERROR_X);
+
+  GST_OBJECT_LOCK (drawable);
+  *scale = drawable->scale;
+  GST_OBJECT_UNLOCK (drawable);
+
+  return PGM_ERROR_OK;
+}
+
 /**
  * pgm_drawable_set_fg_color:
  * @drawable: a #PgmDrawable object.
