@@ -221,9 +221,10 @@ typedef enum {
  * @width: the drawable width.
  * @height: the drawable height.
  * @transformation_matrix: the drawable transformation matrix.
- * @angle_x: the drawable angle of roation on the x axis.
- * @angle_y: the drawable angle of roation on the y axis.
- * @angle_z: the drawable angle of roation on the z axis.
+ * @angle_x: the drawable angle of rotation on the x axis.
+ * @angle_y: the drawable angle of rotation on the y axis.
+ * @angle_z: the drawable angle of rotation on the z axis.
+ * @scale: the drawable scale factor.
  * @fg_r: the drawable foreground red color component.
  * @fg_g: the drawable foreground green color component.
  * @fg_b: the drawable foreground blue color component.
@@ -245,6 +246,9 @@ struct _PgmDrawable {
   /* Position */
   gfloat x, y, z;
 
+  /* Scale */
+  gfloat scale;
+
   /* Size */
   gfloat width, height;
 
@@ -474,6 +478,11 @@ PgmError pgm_drawable_set_rotation_z    (PgmDrawable *drawable,
 PgmError pgm_drawable_get_rotation_z    (PgmDrawable *drawable,
                                          gfloat *angle);
 
+PgmError pgm_drawable_set_scale         (PgmDrawable *drawable,
+                                         gfloat scale);
+PgmError pgm_drawable_get_scale         (PgmDrawable *drawable,
+                                         gfloat *scale);
+
 PgmError pgm_drawable_set_fg_color      (PgmDrawable *drawable,
                                          guchar r,
                                          guchar g,
