@@ -502,7 +502,7 @@ pgm_image_get_type (void)
   if (G_UNLIKELY (image_type == 0))
     {
       static const GTypeInfo image_info = {
-        sizeof (GstElementClass),
+        sizeof (PgmImageClass),
         (GBaseInitFunc) pgm_image_base_class_init,
         (GBaseFinalizeFunc) pgm_image_base_class_finalize,
         (GClassInitFunc) pgm_image_class_init,
@@ -1139,6 +1139,14 @@ pgm_image_set_from_image (PgmImage *image,
 
   GST_OBJECT_LOCK (image);
 
+  /* Do not do anything if the image is already a slave of the source image */
+  if (G_UNLIKELY (src_image == image->master))
+    {
+      GST_OBJECT_UNLOCK (image);
+      ret = PGM_ERROR_OK;
+      goto beach;
+    }
+
   /* Trying to deadlock us? :) */
   if (G_UNLIKELY (image == src_image || image == src_image->master))
     {
