@@ -129,7 +129,10 @@ typedef enum {
 /**
  * PgmImageWrapping:
  * @PGM_IMAGE_CLAMP: The image content is displayed in the mapping range
- * [0.0, 1.0] and discarded outside it.
+ * [0.0, 1.0] and clamped to the last pixel outside it.
+ * @PGM_IMAGE_TRANSPARENT: The image content is displayed in the mapping range
+ * [0.0, 1.0] and discarded outside it. Can be used in combination with the
+ * #PGM_IMAGE_BILINEAR filtering to antialias the edges of images.
  * @PGM_IMAGE_REPEAT: The image content is displayed in the mapping range
  * [0.0, 1.0] and repeated infinitely outside it.
  *
@@ -137,6 +140,7 @@ typedef enum {
  */
 typedef enum {
   PGM_IMAGE_CLAMP,
+  PGM_IMAGE_TRANSPARENT,
   PGM_IMAGE_REPEAT
 } PgmImageWrapping;
 
