@@ -72,10 +72,10 @@ extern void pgm_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                         gpointer      marshal_data);
 void
 pgm_marshal_BOOLEAN__BOXED (GClosure     *closure,
-                            GValue       *return_value,
+                            GValue       *return_value G_GNUC_UNUSED,
                             guint         n_param_values,
                             const GValue *param_values,
-                            gpointer      invocation_hint,
+                            gpointer      invocation_hint G_GNUC_UNUSED,
                             gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__BOXED) (gpointer     data1,
@@ -108,7 +108,52 @@ pgm_marshal_BOOLEAN__BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:OBJECT,UINT (./pgmmarshal.list:32) */
+/* POINTER:BOXED (./pgmmarshal.list:32) */
+extern void pgm_marshal_POINTER__BOXED (GClosure     *closure,
+                                        GValue       *return_value,
+                                        guint         n_param_values,
+                                        const GValue *param_values,
+                                        gpointer      invocation_hint,
+                                        gpointer      marshal_data);
+void
+pgm_marshal_POINTER__BOXED (GClosure     *closure,
+                            GValue       *return_value G_GNUC_UNUSED,
+                            guint         n_param_values,
+                            const GValue *param_values,
+                            gpointer      invocation_hint G_GNUC_UNUSED,
+                            gpointer      marshal_data)
+{
+  typedef gpointer (*GMarshalFunc_POINTER__BOXED) (gpointer     data1,
+                                                   gpointer     arg_1,
+                                                   gpointer     data2);
+  register GMarshalFunc_POINTER__BOXED callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gpointer v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_POINTER__BOXED) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_boxed (param_values + 1),
+                       data2);
+
+  g_value_set_pointer (return_value, v_return);
+}
+
+/* VOID:OBJECT,UINT (./pgmmarshal.list:33) */
 extern void pgm_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -117,10 +162,10 @@ extern void pgm_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                            gpointer      marshal_data);
 void
 pgm_marshal_VOID__OBJECT_UINT (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_UINT) (gpointer     data1,
@@ -151,7 +196,7 @@ pgm_marshal_VOID__OBJECT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT (./pgmmarshal.list:33) */
+/* VOID:OBJECT,OBJECT (./pgmmarshal.list:34) */
 extern void pgm_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -160,10 +205,10 @@ extern void pgm_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              gpointer      marshal_data);
 void
 pgm_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_OBJECT) (gpointer     data1,
@@ -194,7 +239,7 @@ pgm_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT,INT (./pgmmarshal.list:34) */
+/* VOID:OBJECT,OBJECT,INT (./pgmmarshal.list:35) */
 extern void pgm_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -203,10 +248,10 @@ extern void pgm_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
                                                  gpointer      marshal_data);
 void
 pgm_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
-                                     GValue       *return_value,
+                                     GValue       *return_value G_GNUC_UNUSED,
                                      guint         n_param_values,
                                      const GValue *param_values,
-                                     gpointer      invocation_hint,
+                                     gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_OBJECT_INT) (gpointer     data1,
@@ -239,7 +284,7 @@ pgm_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
             data2);
 }
 
-/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT (./pgmmarshal.list:35) */
+/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT (./pgmmarshal.list:36) */
 extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT (GClosure     *closure,
                                                               GValue       *return_value,
                                                               guint         n_param_values,
@@ -248,10 +293,10 @@ extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT (GClosure     *clos
                                                               gpointer      marshal_data);
 void
 pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT (GClosure     *closure,
-                                                  GValue       *return_value,
+                                                  GValue       *return_value G_GNUC_UNUSED,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
-                                                  gpointer      invocation_hint,
+                                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                                   gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT) (gpointer     data1,
@@ -292,7 +337,7 @@ pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT,UINT (./pgmmarshal.list:36) */
+/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT,UINT (./pgmmarshal.list:37) */
 extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT_UINT (GClosure     *closure,
                                                                    GValue       *return_value,
                                                                    guint         n_param_values,
@@ -301,10 +346,10 @@ extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT_UINT (GClosure
                                                                    gpointer      marshal_data);
 void
 pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT_UINT (GClosure     *closure,
-                                                       GValue       *return_value,
+                                                       GValue       *return_value G_GNUC_UNUSED,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
-                                                       gpointer      invocation_hint,
+                                                       gpointer      invocation_hint G_GNUC_UNUSED,
                                                        gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT_UINT) (gpointer     data1,
@@ -347,7 +392,7 @@ pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:37) */
+/* BOOLEAN:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:38) */
 extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -356,10 +401,10 @@ extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
                                                          gpointer      marshal_data);
 void
 pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
-                                             GValue       *return_value,
+                                             GValue       *return_value G_GNUC_UNUSED,
                                              guint         n_param_values,
                                              const GValue *param_values,
-                                             gpointer      invocation_hint,
+                                             gpointer      invocation_hint G_GNUC_UNUSED,
                                              gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__FLOAT_FLOAT_FLOAT_UINT) (gpointer     data1,
@@ -398,7 +443,7 @@ pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:38) */
+/* VOID:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:39) */
 extern void pgm_marshal_VOID__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -407,10 +452,10 @@ extern void pgm_marshal_VOID__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
                                                       gpointer      marshal_data);
 void
 pgm_marshal_VOID__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
-                                          GValue       *return_value,
+                                          GValue       *return_value G_GNUC_UNUSED,
                                           guint         n_param_values,
                                           const GValue *param_values,
-                                          gpointer      invocation_hint,
+                                          gpointer      invocation_hint G_GNUC_UNUSED,
                                           gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__FLOAT_FLOAT_FLOAT_UINT) (gpointer     data1,
@@ -445,7 +490,7 @@ pgm_marshal_VOID__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,UINT,POINTER (./pgmmarshal.list:39) */
+/* VOID:UINT,UINT,POINTER (./pgmmarshal.list:40) */
 extern void pgm_marshal_VOID__UINT_UINT_POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -454,10 +499,10 @@ extern void pgm_marshal_VOID__UINT_UINT_POINTER (GClosure     *closure,
                                                  gpointer      marshal_data);
 void
 pgm_marshal_VOID__UINT_UINT_POINTER (GClosure     *closure,
-                                     GValue       *return_value,
+                                     GValue       *return_value G_GNUC_UNUSED,
                                      guint         n_param_values,
                                      const GValue *param_values,
-                                     gpointer      invocation_hint,
+                                     gpointer      invocation_hint G_GNUC_UNUSED,
                                      gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT_UINT_POINTER) (gpointer     data1,
