@@ -26,7 +26,15 @@ extern void pgm_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* VOID:OBJECT,UINT (./pgmmarshal.list:32) */
+/* POINTER:BOXED (./pgmmarshal.list:32) */
+extern void pgm_marshal_POINTER__BOXED (GClosure     *closure,
+                                        GValue       *return_value,
+                                        guint         n_param_values,
+                                        const GValue *param_values,
+                                        gpointer      invocation_hint,
+                                        gpointer      marshal_data);
+
+/* VOID:OBJECT,UINT (./pgmmarshal.list:33) */
 extern void pgm_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -34,7 +42,7 @@ extern void pgm_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT (./pgmmarshal.list:33) */
+/* VOID:OBJECT,OBJECT (./pgmmarshal.list:34) */
 extern void pgm_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -42,7 +50,7 @@ extern void pgm_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT,INT (./pgmmarshal.list:34) */
+/* VOID:OBJECT,OBJECT,INT (./pgmmarshal.list:35) */
 extern void pgm_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -50,7 +58,7 @@ extern void pgm_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT (./pgmmarshal.list:35) */
+/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT (./pgmmarshal.list:36) */
 extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT (GClosure     *closure,
                                                               GValue       *return_value,
                                                               guint         n_param_values,
@@ -58,7 +66,7 @@ extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT (GClosure     *clos
                                                               gpointer      invocation_hint,
                                                               gpointer      marshal_data);
 
-/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT,UINT (./pgmmarshal.list:36) */
+/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT,UINT (./pgmmarshal.list:37) */
 extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT_UINT (GClosure     *closure,
                                                                    GValue       *return_value,
                                                                    guint         n_param_values,
@@ -66,7 +74,7 @@ extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT_UINT (GClosure
                                                                    gpointer      invocation_hint,
                                                                    gpointer      marshal_data);
 
-/* BOOLEAN:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:37) */
+/* BOOLEAN:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:38) */
 extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -74,7 +82,7 @@ extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);
 
-/* VOID:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:38) */
+/* VOID:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:39) */
 extern void pgm_marshal_VOID__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -82,7 +90,7 @@ extern void pgm_marshal_VOID__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);
 
-/* VOID:UINT,UINT,POINTER (./pgmmarshal.list:39) */
+/* VOID:UINT,UINT,POINTER (./pgmmarshal.list:40) */
 extern void pgm_marshal_VOID__UINT_UINT_POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
