@@ -35,6 +35,9 @@ typedef struct _PgmViewportClass PgmViewportClass;
 #include "pgmviewportfactory.h"
 #include "pgmlinearalgebra.h"
 #include "pgmevents.h"
+#ifdef WIN32
+#include <Windows.h>
+#endif /* WIN32 */
 
 G_BEGIN_DECLS
 
@@ -320,8 +323,10 @@ struct _PgmViewportClass {
   void     (*state_event)           (PgmViewport *viewport,
                                      PgmEventState *event);
 
-  void     (*win32_message_event)   (PgmViewport *viewport,
+#ifdef WIN32
+  LRESULT  (*win32_message_event)   (PgmViewport *viewport,
                                      PgmEventWin32Message *event);
+#endif /* WIN32 */
 
   void     (*pixels_read)           (PgmViewport *viewport,
                                      guint width,
@@ -554,6 +559,16 @@ PgmError     pgm_viewport_push_pixels           (PgmViewport *viewport,
 
 PgmError     pgm_viewport_emit_update_pass      (PgmViewport *viewport);
 
+
+/* Protected methods */
+
+#ifdef WIN32
+PgmError _pgm_viewport_push_win32_message (PgmViewport *viewport,
+                                           PgmEvent *event,
+                                           gint32 *message_processed,
+                                           LRESULT *result);
+#endif /* WIN32 */
+
 G_END_DECLS
 
 #endif /* __PGM_VIEWPORT_H__ */
