@@ -229,6 +229,35 @@ pgm_backend_set_visibility (PgmBackend *backend,
   return FALSE;
 }
 
+gboolean
+pgm_backend_set_iconified (PgmBackend *backend,
+                           gboolean iconified)
+{
+  PgmBackendClass *klass;
+
+  g_return_val_if_fail (PGM_IS_BACKEND (backend), FALSE);
+
+  klass = PGM_BACKEND_GET_CLASS (backend);
+
+  if (klass->set_iconified)
+    klass->set_iconified (backend, iconified);
+
+  return FALSE;
+}
+
+void
+pgm_backend_focus (PgmBackend *backend)
+{
+  PgmBackendClass *klass;
+
+  g_return_if_fail (PGM_IS_BACKEND (backend));
+
+  klass = PGM_BACKEND_GET_CLASS (backend);
+
+  if (klass->focus)
+    klass->focus (backend);
+}
+
 void
 pgm_backend_get_screen_size_mm (PgmBackend *backend,
                                 gint *width,
