@@ -104,6 +104,7 @@ struct _PgmContext {
   /* Auto-update */
   GMutex   *update_mutex;
   gboolean  auto_updated;
+  gboolean  prevent_update;
   GTimeVal  update_timestamp;
   guint     update_tag;
   guint     requested_fps;
@@ -304,6 +305,10 @@ void            pgm_context_push_deferred_task     (PgmContext *context,
 void            pgm_context_remove_tasks_with_data (PgmContext *context,
                                                     gconstpointer data);
 
+/* Prevent rendering updates when window is fully obscured or iconified */
+void            pgm_context_prevent_update         (PgmContext *context,
+                                                    gboolean prevent);
+
 /* Dump a formatted output on stdout showing informations about the GPU */
 void            pgm_context_dump_features          (PgmContext *context);
 
