@@ -132,6 +132,7 @@ pgm_gl_drawable_sync (PgmGlDrawable *gldrawable)
   update_size (gldrawable);
   pgm_gl_drawable_set_position (gldrawable);
   pgm_gl_drawable_set_bg_color (gldrawable);
+  pgm_gl_drawable_set_transformation_matrix (gldrawable);
 
   klass = PGM_GL_DRAWABLE_GET_CLASS (gldrawable);
 
@@ -165,6 +166,13 @@ pgm_gl_drawable_draw (PgmGlDrawable *gldrawable)
 
   gl = gldrawable->glviewport->context->gl;
 
+  /* Push and set the modelview matrix for the drawable if needed */
+  if (!(gldrawable->flags & PGM_GL_DRAWABLE_IDENTITY_MATRIX))
+    {
+      gl->push_matrix ();
+      gl->load_matrix_f (gldrawable->transformation_matrix->m);
+    }
+
   /* Batch background array if it's visible */
   if (gldrawable->bg_color[3] != 0.0f)
     {
@@ -180,6 +188,10 @@ pgm_gl_drawable_draw (PgmGlDrawable *gldrawable)
 
   if (klass && klass->draw)
     klass->draw (gldrawable);
+
+  /* Pop the modelview matrix if needed */
+  if (!(gldrawable->flags & PGM_GL_DRAWABLE_IDENTITY_MATRIX))
+    gl->pop_matrix ();
 }
 
 void
@@ -278,6 +290,35 @@ pgm_gl_drawable_set_position (PgmGlDrawable *gldrawable)
     klass->set_position (gldrawable);
 }
 
+void
+pgm_gl_drawable_set_transformation_matrix (PgmGlDrawable *gldrawable)
+{
+  PgmDrawable *drawable = gldrawable->drawable;
+  PgmGlDrawableClass *klass;
+  PgmMat4x4 matrix;
+
+  g_return_if_fail (PGM_IS_GL_DRAWABLE (gldrawable));
+
+  GST_DEBUG_OBJECT (gldrawable, "set_transformation_matrix");
+
+  klass = PGM_GL_DRAWABLE_GET_CLASS (gldrawable);
+
+  /* Store the matrix */
+  GST_OBJECT_LOCK (drawable);
+  pgm_mat4x4_set_from_mat4x4 (&matrix, drawable->transformation_matrix);
+  GST_OBJECT_UNLOCK (drawable);
+  gldrawable->transformation_matrix = pgm_mat4x4_transpose (&matrix);
+
+  /* Check identity so that we can avoid pushing the matrix at rendering */
+  if (G_UNLIKELY (pgm_mat4x4_is_identity (gldrawable->transformation_matrix)))
+    gldrawable->flags |= PGM_GL_DRAWABLE_IDENTITY_MATRIX;
+  else
+    gldrawable->flags &= ~PGM_GL_DRAWABLE_IDENTITY_MATRIX;
+
+  if (klass->set_transformation_matrix)
+    klass->set_transformation_matrix (gldrawable);
+}
+
 void
 pgm_gl_drawable_set_fg_color (PgmGlDrawable *gldrawable)
 {
@@ -291,7 +332,6 @@ pgm_gl_drawable_set_fg_color (PgmGlDrawable *gldrawable)
 
   if (klass->set_fg_color)
     klass->set_fg_color (gldrawable);
-
 }
 
 void
