@@ -51,6 +51,11 @@ G_BEGIN_DECLS
 #define INV_255     0.003921568627f
 #define SQR_INV_255 0.0000153787f
 
+/* Flags */
+typedef enum {
+  PGM_GL_DRAWABLE_IDENTITY_MATRIX = (1 << 0)
+} PgmGlDrawableFlags;
+
 struct _PgmGlDrawable {
   GstObject parent;
 
@@ -70,38 +75,46 @@ struct _PgmGlDrawable {
   /* Background vertex arrays */
   PgmGlFloat bg_color[4];
   PgmGlFloat bg_vertex[12];
+
+  /* Transformation */
+  PgmMat4x4 *transformation_matrix;
+
+  /* Flags */
+  PgmGlDrawableFlags flags;
 };
 
 struct _PgmGlDrawableClass {
   GstObjectClass parent_class;
 
   /* virtual methods for subclasses */
-  void (*sync)              (PgmGlDrawable *gldrawable);
-  void (*draw)              (PgmGlDrawable *gldrawable);
-  void (*regenerate)        (PgmGlDrawable *gldrawable);
-  void (*update_projection) (PgmGlDrawable *gldrawable);
-  void (*set_visibility)    (PgmGlDrawable *gldrawable);
-  void (*set_size)          (PgmGlDrawable *gldrawable);
-  void (*set_position)      (PgmGlDrawable *gldrawable);
-  void (*set_fg_color)      (PgmGlDrawable *gldrawable);
-  void (*set_bg_color)      (PgmGlDrawable *gldrawable);
-  void (*set_opacity)       (PgmGlDrawable *gldrawable);
+  void (*sync)                      (PgmGlDrawable *gldrawable);
+  void (*draw)                      (PgmGlDrawable *gldrawable);
+  void (*regenerate)                (PgmGlDrawable *gldrawable);
+  void (*update_projection)         (PgmGlDrawable *gldrawable);
+  void (*set_visibility)            (PgmGlDrawable *gldrawable);
+  void (*set_size)                  (PgmGlDrawable *gldrawable);
+  void (*set_position)              (PgmGlDrawable *gldrawable);
+  void (*set_transformation_matrix) (PgmGlDrawable *gldrawable);
+  void (*set_fg_color)              (PgmGlDrawable *gldrawable);
+  void (*set_bg_color)              (PgmGlDrawable *gldrawable);
+  void (*set_opacity)               (PgmGlDrawable *gldrawable);
 };
 
-GType pgm_gl_drawable_get_type          (void) G_GNUC_CONST;
+GType pgm_gl_drawable_get_type                  (void) G_GNUC_CONST;
 
-void  pgm_gl_drawable_register          (GTypeModule *module);
+void  pgm_gl_drawable_register                  (GTypeModule *module);
 
-void  pgm_gl_drawable_sync              (PgmGlDrawable *gldrawable);
-void  pgm_gl_drawable_draw              (PgmGlDrawable *gldrawable);
-void  pgm_gl_drawable_regenerate        (PgmGlDrawable *gldrawable);
-void  pgm_gl_drawable_update_projection (PgmGlDrawable *gldrawable);
-void  pgm_gl_drawable_set_visibility    (PgmGlDrawable *gldrawable);
-void  pgm_gl_drawable_set_size          (PgmGlDrawable *gldrawable);
-void  pgm_gl_drawable_set_position      (PgmGlDrawable *gldrawable);
-void  pgm_gl_drawable_set_fg_color      (PgmGlDrawable *gldrawable);
-void  pgm_gl_drawable_set_bg_color      (PgmGlDrawable *gldrawable);
-void  pgm_gl_drawable_set_opacity       (PgmGlDrawable *gldrawable);
+void  pgm_gl_drawable_sync                      (PgmGlDrawable *gldrawable);
+void  pgm_gl_drawable_draw                      (PgmGlDrawable *gldrawable);
+void  pgm_gl_drawable_regenerate                (PgmGlDrawable *gldrawable);
+void  pgm_gl_drawable_update_projection         (PgmGlDrawable *gldrawable);
+void  pgm_gl_drawable_set_visibility            (PgmGlDrawable *gldrawable);
+void  pgm_gl_drawable_set_size                  (PgmGlDrawable *gldrawable);
+void  pgm_gl_drawable_set_position              (PgmGlDrawable *gldrawable);
+void  pgm_gl_drawable_set_transformation_matrix (PgmGlDrawable *gldrawable);
+void  pgm_gl_drawable_set_fg_color              (PgmGlDrawable *gldrawable);
+void  pgm_gl_drawable_set_bg_color              (PgmGlDrawable *gldrawable);
+void  pgm_gl_drawable_set_opacity               (PgmGlDrawable *gldrawable);
 
 G_END_DECLS
 
