@@ -78,58 +78,86 @@ static PgmGlDrawableClass *parent_class = NULL;
 
 /* Private methods */
 
-/* Gets the projected height of the drawable on the viewport */
+/* Gets the projected height of the drawable on the viewport at z=0 */
 static gfloat
 get_projected_height (PgmGlDrawable *gldrawable,
                       gfloat canvas_height)
 {
   PgmGlViewport *glviewport = gldrawable->glviewport;
   PgmViewport *viewport = PGM_VIEWPORT (glviewport);
-  PgmCanvas *canvas = viewport->canvas;
   gfloat height;
 
-  /* FIXME: That's just the projected height on z=0 */
-  GST_OBJECT_LOCK (canvas);
   GST_OBJECT_LOCK (viewport);
-
-  if (viewport->rotation == PGM_VIEWPORT_ROTATION_NONE
-      || viewport->rotation == PGM_VIEWPORT_ROTATION_180)
-    height = (canvas_height * viewport->projected_height) / canvas->height;
-  else
-    height = (canvas_height * viewport->projected_height) / canvas->width;
-
+  height = (canvas_height * glviewport->projected_h) / glviewport->canvas_h;
   GST_OBJECT_UNLOCK (viewport);
-  GST_OBJECT_UNLOCK (canvas);
 
   return height;
 }
 
-/* Gets the projected width of the drawable on the viewport */
+/* Gets the projected width of the drawable on the viewport at z=0 */
 static gfloat
 get_projected_width (PgmGlDrawable *gldrawable,
                      gfloat canvas_width)
 {
   PgmGlViewport *glviewport = gldrawable->glviewport;
   PgmViewport *viewport = PGM_VIEWPORT (glviewport);
-  PgmCanvas *canvas = viewport->canvas;
   gfloat width;
 
-  /* FIXME: That's just the projected width on z=0 */
-  GST_OBJECT_LOCK (canvas);
   GST_OBJECT_LOCK (viewport);
-
-  if (viewport->rotation == PGM_VIEWPORT_ROTATION_NONE
-      || viewport->rotation == PGM_VIEWPORT_ROTATION_180)
-    width = (canvas_width * viewport->projected_width) / canvas->width;
-  else
-    width = (canvas_width * viewport->projected_width) / canvas->height;
-
+  width = (canvas_width * glviewport->projected_w) / glviewport->canvas_w;
   GST_OBJECT_UNLOCK (viewport);
-  GST_OBJECT_UNLOCK (canvas);
 
   return width;
 }
 
+/* Sets the position of the text taking care of aligning the vertices to the
+ * pixel boundaries. It ensures clean text rendering without any artifact
+ * implied by the sub-pixels rasterization process. */
+static void
+set_position (PgmGlDrawable *gldrawable)
+{
+  PgmGlViewport *glviewport = gldrawable->glviewport;
+  PgmGlText *gltext = PGM_GL_TEXT (gldrawable);
+  gfloat offset_x = glviewport->pixel_offset_x;
+  gfloat offset_y = glviewport->pixel_offset_y;
+  gfloat bound_width = floorf (gldrawable->width / offset_x) * offset_x;
+  gfloat bound_height = floorf (gldrawable->height / offset_y) * offset_y;
+  gfloat bound_x = floorf (gldrawable->x / offset_x) * offset_x;
+  gfloat bound_y = floorf (gldrawable->y / offset_y) * offset_y;
+
+  gltext->vertex[0] = bound_x;
+  gltext->vertex[1] = bound_y;
+  gltext->vertex[2] = gldrawable->z;
+  gltext->vertex[3] = bound_x + bound_width;
+  gltext->vertex[4] = bound_y;
+  gltext->vertex[5] = gldrawable->z;
+  gltext->vertex[6] = gltext->vertex[3];
+  gltext->vertex[7] = bound_y + bound_height;
+  gltext->vertex[8] = gldrawable->z;
+  gltext->vertex[9] = bound_x;
+  gltext->vertex[10] = gltext->vertex[7];
+  gltext->vertex[11] = gldrawable->z;
+}
+
+/* Sets the size of the text taking care of aligning the vertices to the
+ * pixel boundaries. It ensures clean text rendering without any artifact
+ * implied by the sub-pixels rasterization process. */
+static void
+set_size (PgmGlDrawable *gldrawable)
+{
+  PgmGlViewport *glviewport = gldrawable->glviewport;
+  PgmGlText *gltext = PGM_GL_TEXT (gldrawable);
+  gfloat offset_x = glviewport->pixel_offset_x;
+  gfloat offset_y = glviewport->pixel_offset_y;
+  gfloat bound_width = floorf (gldrawable->width / offset_x) * offset_x;
+  gfloat bound_height = floorf (gldrawable->height / offset_y) * offset_y;
+
+  gltext->vertex[3] = gldrawable->bg_vertex[0] + bound_width;
+  gltext->vertex[6] = gltext->vertex[3];
+  gltext->vertex[7] = gldrawable->bg_vertex[1] + bound_height;
+  gltext->vertex[10] = gltext->vertex[7];
+}
+
 /* Defines texture coordinates */
 static void
 set_coordinates (PgmGlText *gltext)
@@ -613,15 +641,25 @@ create_pixmap (PgmGlText *gltext)
   PgmGlDrawable *gldrawable = PGM_GL_DRAWABLE (gltext);
   PgmViewport *viewport = PGM_VIEWPORT (gldrawable->glviewport);
   PgmContextTask *task;
-  gfloat pixel_aspect_ratio;
+  gfloat sx, sy;
 
-  gltext->width = (guint) get_projected_width (gldrawable,
-                                               gldrawable->width);
-  gltext->height = (guint) get_projected_height (gldrawable,
-                                                 gldrawable->height);
+  gltext->width =
+    MAX (1, (guint) get_projected_width (gldrawable, gldrawable->width));
+  gltext->height =
+    MAX (1, (guint) get_projected_height (gldrawable, gldrawable->height));
 
   GST_OBJECT_LOCK (viewport);
-  pixel_aspect_ratio = viewport->pixel_aspect_ratio;
+  if (viewport->rotation == PGM_VIEWPORT_ROTATION_NONE
+      || viewport->rotation == PGM_VIEWPORT_ROTATION_180)
+    {
+      sx = viewport->pixel_aspect_ratio;
+      sy = 1.0f;
+    }
+  else
+    {
+      sx = 1.0f;
+      sy = viewport->pixel_aspect_ratio;
+    }
   GST_OBJECT_UNLOCK (viewport);
 
   gltext->size = gltext->width * gltext->height * 4;
@@ -634,7 +672,7 @@ create_pixmap (PgmGlText *gltext)
 
   gltext->cairo_ctx = cairo_create (gltext->surface);
   cairo_set_font_options (gltext->cairo_ctx, gltext->font_options);
-  cairo_scale (gltext->cairo_ctx, pixel_aspect_ratio, 1.0f);
+  cairo_scale (gltext->cairo_ctx, sx, sy);
   gltext->layout = pango_cairo_create_layout (gltext->cairo_ctx);
   gltext->pango_ctx = pango_layout_get_context (gltext->layout);
 
@@ -729,6 +767,7 @@ regenerate_text (PgmGlText *gltext)
   create_pixmap (gltext);
   update_properties (gltext);
   update_pixmap (gltext);
+  set_position (PGM_GL_DRAWABLE (gltext));
 }
 
 /* Update a text by simply generating the new one in the current allocated
@@ -801,12 +840,10 @@ static void
 pgm_gl_text_set_size (PgmGlDrawable *gldrawable)
 {
   PgmGlText *gltext = PGM_GL_TEXT (gldrawable);
-  guint i;
 
   GST_DEBUG_OBJECT (gldrawable, "set_size");
 
-  for (i = 0; i < 12; i++)
-    gltext->vertex[i] = gldrawable->bg_vertex[i];
+  set_size (gldrawable);
 
   gltext->size_updated = TRUE;
 }
@@ -814,13 +851,9 @@ pgm_gl_text_set_size (PgmGlDrawable *gldrawable)
 static void
 pgm_gl_text_set_position (PgmGlDrawable *gldrawable)
 {
-  PgmGlText *gltext = PGM_GL_TEXT (gldrawable);
-  guint i;
-
   GST_DEBUG_OBJECT (gldrawable, "set_position");
 
-  for (i = 0; i < 12; i++)
-    gltext->vertex[i] = gldrawable->bg_vertex[i];
+  set_position (gldrawable);
 }
 
 static void
@@ -973,6 +1006,7 @@ pgm_gl_text_new (PgmDrawable *drawable,
   GST_DEBUG_OBJECT (gltext, "created new gltext");
 
   gltext->texture = pgm_texture_new (glviewport->context);
+  gltext->texture->filter = PGM_GL_NEAREST;
 
   gldrawable = PGM_GL_DRAWABLE (gltext);
   gldrawable->drawable = gst_object_ref (drawable);
