@@ -1016,6 +1016,37 @@ pgm_gl_viewport_update_projection (PgmViewport *viewport)
 
   GST_DEBUG_OBJECT (glviewport, "update_projection");
 
+  GST_OBJECT_LOCK (viewport);
+
+  /* Store the projected size  */
+  if (viewport->rotation == PGM_VIEWPORT_ROTATION_NONE
+      || viewport->rotation == PGM_VIEWPORT_ROTATION_180)
+    {
+      glviewport->projected_w = (gfloat) viewport->projected_width;
+      glviewport->projected_h = (gfloat) viewport->projected_height;
+    }
+  else
+    {
+      glviewport->projected_w = (gfloat) viewport->projected_height;
+      glviewport->projected_h = (gfloat) viewport->projected_width;
+    }
+
+  /* Store the canvas size */
+  if (viewport->canvas)
+    {
+      GST_OBJECT_LOCK (viewport->canvas);
+      glviewport->canvas_w = viewport->canvas->width;
+      glviewport->canvas_h = viewport->canvas->height;
+      GST_OBJECT_UNLOCK (viewport->canvas);
+    }
+
+  GST_OBJECT_UNLOCK (viewport);
+
+  /* Deduct the pixel boundary offsets */
+  glviewport->pixel_offset_x = glviewport->canvas_w / glviewport->projected_w;
+  glviewport->pixel_offset_y = glviewport->canvas_h / glviewport->projected_h;
+
+  /* And queue the projection update task */
   task = pgm_context_task_new (PGM_CONTEXT_PROJECTION, NULL);
   pgm_context_push_immediate_task (glviewport->context, task);
 
@@ -1378,6 +1409,14 @@ pgm_gl_viewport_init (PgmGlViewport *glviewport)
   /* Create context */
   glviewport->context = pgm_context_new (glviewport);
 
+  /* Projection informations */
+  glviewport->projected_w = 800;
+  glviewport->projected_h = 600;
+  glviewport->canvas_w = 4.0f;
+  glviewport->canvas_h = 3.0f;
+  glviewport->pixel_offset_x = 0.005f;
+  glviewport->pixel_offset_y = 0.0005f;
+
   /* Fill capacities */
   glviewport->capacities = 0;
   if (pgm_backend_is_accelerated (glviewport->context->backend))
