@@ -79,6 +79,14 @@ struct _PgmGlViewport {
   GSList *update_queue;
   GMutex *update_lock;
 
+  /* Projection informations */
+  gfloat projected_w;
+  gfloat projected_h;
+  gfloat canvas_w;
+  gfloat canvas_h;
+  gfloat pixel_offset_x;
+  gfloat pixel_offset_y;
+
   /* Capacities mask */
   gulong capacities;
 
