@@ -167,7 +167,7 @@ typedef enum {
   ATOM_XDND_SELECTION          = 22,
   ATOM_XDND_STATUS             = 23,
   ATOM_XDND_FINISHED           = 24,
-  ATOM_XDND_ACTION_COPY        = 25,
+  ATOM_XDND_ACTION_LINK        = 25,
   ATOM_TEXT_URI_LIST           = 26
 } XAtomIndexId;
 
@@ -198,7 +198,7 @@ static const gchar *atom_name[] = {
   "XdndSelection",            /* 22 */
   "XdndStatus",               /* 23 */
   "XdndFinished",             /* 24 */
-  "XdndActionCopy",           /* 25 */
+  "XdndActionLink",           /* 25 */
   "text/uri-list"             /* 26 */
 };
 
@@ -888,7 +888,7 @@ update_xdnd_status (PgmGlxBackend *glxbackend)
       GST_DEBUG_OBJECT (glxbackend, "sending message accepting xdnd drag");
       send_xdnd_message (glxbackend, glxbackend->drag_source,
                          glxbackend->atom[ATOM_XDND_STATUS], 1 | 2, 0, 0,
-                         glxbackend->atom[ATOM_XDND_ACTION_COPY]);
+                         glxbackend->atom[ATOM_XDND_ACTION_LINK]);
     }
   /* Refuse but request next XdndPosition message */
   else
@@ -1058,7 +1058,7 @@ handle_xdnd_drop_event (PgmGlxBackend *glxbackend,
 
       send_xdnd_message (glxbackend, glxbackend->drag_source,
                          glxbackend->atom[ATOM_XDND_FINISHED], 1, None, None,
-                         glxbackend->atom[ATOM_XDND_ACTION_COPY]);
+                         glxbackend->atom[ATOM_XDND_ACTION_LINK]);
     }
   else
     {
@@ -1906,6 +1906,14 @@ pgm_glx_backend_create_window (PgmBackend *backend)
   glxbackend->size_mm_height =
     DisplayHeightMM (glxbackend->dpy, glxbackend->screen);
 
+  /* X sometimes reports broken size of 1 mm */
+  if (glxbackend->size_mm_width == 1
+      || glxbackend->size_mm_height == 1)
+    {
+      glxbackend->size_mm_width = glxbackend->resolution_width;
+      glxbackend->size_mm_height = glxbackend->resolution_height;
+    }
+
   glxbackend->none_cursor = get_none_cursor (glxbackend);
 
   gdk_pixbuf_xlib_init (glxbackend->dpy, glxbackend->screen);
